#
# spec file for package python-idna
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-idna
Version:        3.7
Release:        1.1
Summary:        Internationalized Domain Names in Applications (IDNA)
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/kjd/idna
Source0:        https://files.pythonhosted.org/packages/source/i/idna/idna-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros >= 20220106.80d3756
BuildArch:      noarch
%python_subpackages

%description
A library to support the Internationalised Domain Names in
Applications (IDNA) protocol as specified in RFC 5891
http://tools.ietf.org/html/rfc5891. This version of the protocol
is often referred to as “IDNA2008” and can produce different
results from the earlier standard from 2003.

The library is also intended to act as a suitable drop-in replacement
for the “encodings.idna” module that comes with the Python standard
library but currently only supports the older 2003 specification.

%prep
%autosetup -p1 -n idna-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest discover -v

%files %{python_files}
%license LICENSE.md
%doc README.rst
%{python_sitelib}/idna
%{python_sitelib}/idna-%{version}*-info

%changelog
* Thu Apr 18 2024 Daniel Garcia <daniel.garcia@suse.com>
- update to 3.7 (bsc#1222842, CVE-2024-3651):
  * Fix issue where specially crafted inputs to encode() could take
    exceptionally long amount of time to process. [CVE-2024-3651]
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 3.6:
  * Fix regression to include tests in source distribution.
  * Update to Unicode 15.1.0
  * String codec name is now "idna2008" as overriding the system codec
    "idna" was not working.
  * Fix typing error for codec encoding
  * "setup.cfg" has been added for this release due to some downstream
  * lack of adherence to PEP 517. Should be removed in a future release
    so please prepare accordingly.
  * Removed reliance on a symlink for the "idna-data" tool to comport
    with PEP 517 and the Python Packaging User Guide for sdist
    archives.
  * Added security reporting protocol for project
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Fri Sep 16 2022 Dirk Müller <dmueller@suse.com>
- update to 3.4:
  * Update to Unicode 15.0.0
  * Migrate to pyproject.toml for build information (PEP 621)
  * Correct another instance where generic exception was raised instead of
    IDNAError for malformed input
  * Source distribution uses zeroized file ownership for improved
    reproducibility
* Thu Jun 30 2022 Johannes Kastl <kastl@b1-systems.de>
- add version constraint for python-rpm-macros >= 20220106.80d3756,
  otherwise this fails to build on 15.3 at '%%pyunittest discover -v'
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 3.3:
  - Update to Unicode 14.0.0
  - Update to in-line type annotations
  - Throw IDNAError exception correctly for some malformed input
  - Advertise support for Python 3.10
  - Improve testing regime on Github
  - Fix Russian typo in documentation
* Sun Jun  6 2021 Dirk Müller <dmueller@suse.com>
- update to 3.2:
  * Add type hints (Thanks, Seth Michael Larson!)
  * Remove support for Python 3.4
* Wed May 26 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Tue Feb  2 2021 Dirk Müller <dmueller@suse.com>
- update to 3.1:
  - Ensure license is included in package (Thanks, Julien Schueller)
  - No longer mark wheel has universal (Thanks, Matthieu Darbois)
  - Test on PowerPC using Travis CI
  - Python 2 is no longer supported (the 2.x branch supports Python 2,
    use "idna<3" in your requirements file if you need Python 2 support)
  - Support for V2 UTS 46 test vectors.
* Fri Jul 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.10:
  - Update to Unicode 13.0.0.
  - Throws a more specific exception if "xn--" is provided as a label.
  - This is expected to be the last version that supports Python 2.
* Fri Feb 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.9:
  - Update to Unicode 12.1.0.
  - Prohibit A-labels ending with a hyphen (Thanks, Julien Bernard!)
  - Future-proofing: Test on Python 3.7 and 3.8, don't immediately
    fail should Python 4 come along.
-   Made BSD 3-clause license clearer
* Sun Feb 17 2019 John Vandenberg <jayvdb@gmail.com>
- Update to version 2.8
  * Update to Unicode 11.0.0.
  * Provide more specific exceptions for some malformed labels.
- Add fdupes
* Mon Jul  2 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 2.7:
  * Update to Unicode 10.0.0.
  * No longer accepts dot-prefixed domains (e.g. ".example") as
    valid. This is to be more conformant with the UTS 46 spec. Users
    should strip dot prefixes from domains before processing.
* Thu Nov  9 2017 arun@gmx.de
- update to version 2.6:
  * Allows generation of IDNA and UTS 46 table data for different
    versions of Unicode, by deriving properties directly from Unicode
    data.
  * Ability to generate RFC 5892/IANA-style table data
  * Diagnostic output of IDNA-related Unicode properties and derived
    calculations for a given codepoint
  * Support for idna.__version__ to report version
  * Support for idna.idnadata.__version__ and
    idna.uts46data.__version__ to report Unicode version of underlying
    IDNA and UTS 46 data respectively.
* Tue Mar 21 2017 jmatejek@suse.com
- point download url to PyPI
- drop %%oname
* Thu Mar 16 2017 tbechtold@suse.com
- update to version v2.5
  * only store scripts that are specifically referenced in logic
  * Fix validation for U+30FB KATAKANA MIDDLE DOT code point (#47)
  * range-based integer containment code
  * Documentation Updates
  * Make test runners Python 2.6 compatible (issue #20)
  * remove DISALLOWED codepoints from datafile, since they're unread
  * Avoid using bare 'except' (#39)
  * Add Python 3.5 support
  * Mark Python Wheels as universal (supports Python 2 and 3)
  * Skip tests that won't work on Python 2.6 (fixes #20)
  * Update Travis configuration to test against Python 2.6 and 3.6
  * Use relative imports (fixes #26)
  * Documentation tidy up
  * Revert to basing IDNAError on UnicodeError (issue #43) (#45)
  * rebuild idnadata
  * Update history with Java-related change
  * ignore vim swapfiles
  * Update Travis CI coverage to 3.6 and 3.7-dev
  * Reduce memory usage even further. (#41)
  * Update trove classifier for Python 3.6
  * Properly report label length exceptions (issue #36)
  * Segment uts46data to avoid Jython limits (#28)
- Switch to singlespec approach
* Fri Jul 17 2015 nemysis@gmx.ch
- Initial package creation
